@@ -31,10 +31,10 @@ class QCheckBox_hook : public QAbstractButton_hook {
     }
 
   private slots:
-    void stateChanged_hook(int p1) {
+    void stateChanged_hook(int AnonParam1) {
       if ( stateChanged_event.func ) {
-        typedef void (*func_type)(void *data, int p1);
-	(*(func_type)stateChanged_event.func)(stateChanged_event.data, p1);
+        typedef void (*func_type)(void *data, int AnonParam1);
+	(*(func_type)stateChanged_event.func)(stateChanged_event.data, AnonParam1);
       }
     }
   private:
