@@ -647,14 +647,14 @@ const char* QDropEvent_format(QDropEventH handle, int n)
 	return (const char*) ((QDropEvent *)handle)->format(n);
 }
 
-void QDropEvent_encodedData(QDropEventH handle, QByteArrayH retval, const char* p1)
+void QDropEvent_encodedData(QDropEventH handle, QByteArrayH retval, const char* AnonParam1)
 {
-	*(QByteArray *)retval = ((QDropEvent *)handle)->encodedData(p1);
+	*(QByteArray *)retval = ((QDropEvent *)handle)->encodedData(AnonParam1);
 }
 
-bool QDropEvent_provides(QDropEventH handle, const char* p1)
+bool QDropEvent_provides(QDropEventH handle, const char* AnonParam1)
 {
-	return (bool) ((QDropEvent *)handle)->provides(p1);
+	return (bool) ((QDropEvent *)handle)->provides(AnonParam1);
 }
 
 QDragMoveEventH QDragMoveEvent_create(const QPointH pos, unsigned int actions, const QMimeDataH data, unsigned int buttons, unsigned int modifiers, QEvent::Type type)
