@@ -18,18 +18,18 @@
 C_EXPORT QFrameH QFrame_create(QWidgetH parent, unsigned int f);
 C_EXPORT void QFrame_destroy(QFrameH handle);
 C_EXPORT int QFrame_frameStyle(QFrameH handle);
-C_EXPORT void QFrame_setFrameStyle(QFrameH handle, int p1);
+C_EXPORT void QFrame_setFrameStyle(QFrameH handle, int AnonParam1);
 C_EXPORT int QFrame_frameWidth(QFrameH handle);
 C_EXPORT void QFrame_sizeHint(QFrameH handle, PSize retval);
 C_EXPORT QFrame::Shape QFrame_frameShape(QFrameH handle);
-C_EXPORT void QFrame_setFrameShape(QFrameH handle, QFrame::Shape p1);
+C_EXPORT void QFrame_setFrameShape(QFrameH handle, QFrame::Shape AnonParam1);
 C_EXPORT QFrame::Shadow QFrame_frameShadow(QFrameH handle);
-C_EXPORT void QFrame_setFrameShadow(QFrameH handle, QFrame::Shadow p1);
+C_EXPORT void QFrame_setFrameShadow(QFrameH handle, QFrame::Shadow AnonParam1);
 C_EXPORT int QFrame_lineWidth(QFrameH handle);
-C_EXPORT void QFrame_setLineWidth(QFrameH handle, int p1);
+C_EXPORT void QFrame_setLineWidth(QFrameH handle, int AnonParam1);
 C_EXPORT int QFrame_midLineWidth(QFrameH handle);
-C_EXPORT void QFrame_setMidLineWidth(QFrameH handle, int p1);
+C_EXPORT void QFrame_setMidLineWidth(QFrameH handle, int AnonParam1);
 C_EXPORT void QFrame_frameRect(QFrameH handle, PRect retval);
-C_EXPORT void QFrame_setFrameRect(QFrameH handle, PRect p1);
+C_EXPORT void QFrame_setFrameRect(QFrameH handle, PRect AnonParam1);
 
 #endif
