@@ -21,9 +21,9 @@ void QPainter_destroy(QPainterH handle)
 	delete (QPainter *)handle;
 }
 
-QPainterH QPainter_create2(QPaintDeviceH p1)
+QPainterH QPainter_create2(QPaintDeviceH AnonParam1)
 {
-	return (QPainterH) new QPainter((QPaintDevice*)p1);
+	return (QPainterH) new QPainter((QPaintDevice*)AnonParam1);
 }
 
 QPaintDeviceH QPainter_device(QPainterH handle)
@@ -31,9 +31,9 @@ QPaintDeviceH QPainter_device(QPainterH handle)
 	return (QPaintDeviceH) ((QPainter *)handle)->device();
 }
 
-bool QPainter_begin(QPainterH handle, QPaintDeviceH p1)
+bool QPainter_begin(QPainterH handle, QPaintDeviceH AnonParam1)
 {
-	return (bool) ((QPainter *)handle)->begin((QPaintDevice*)p1);
+	return (bool) ((QPainter *)handle)->begin((QPaintDevice*)AnonParam1);
 }
 
 bool QPainter_end(QPainterH handle)
@@ -136,14 +136,14 @@ void QPainter_setBrushOrigin(QPainterH handle, int x, int y)
 	((QPainter *)handle)->setBrushOrigin(x, y);
 }
 
-void QPainter_setBrushOrigin2(QPainterH handle, const QPointH p1)
+void QPainter_setBrushOrigin2(QPainterH handle, const QPointH AnonParam1)
 {
-	((QPainter *)handle)->setBrushOrigin(*(const QPoint*)p1);
+	((QPainter *)handle)->setBrushOrigin(*(const QPoint*)AnonParam1);
 }
 
-void QPainter_setBrushOrigin3(QPainterH handle, const QPointFH p1)
+void QPainter_setBrushOrigin3(QPainterH handle, const QPointFH AnonParam1)
 {
-	((QPainter *)handle)->setBrushOrigin(*(const QPointF*)p1);
+	((QPainter *)handle)->setBrushOrigin(*(const QPointF*)AnonParam1);
 }
 
 void QPainter_setBackground(QPainterH handle, const QBrushH bg)
@@ -176,16 +176,16 @@ void QPainter_clipPath(QPainterH handle, QPainterPathH retval)
 	*(QPainterPath *)retval = ((QPainter *)handle)->clipPath();
 }
 
-void QPainter_setClipRect(QPainterH handle, const QRectFH p1, Qt::ClipOperation op)
+void QPainter_setClipRect(QPainterH handle, const QRectFH AnonParam1, Qt::ClipOperation op)
 {
-	((QPainter *)handle)->setClipRect(*(const QRectF*)p1, op);
+	((QPainter *)handle)->setClipRect(*(const QRectF*)AnonParam1, op);
 }
 
-void QPainter_setClipRect2(QPainterH handle, PRect p1, Qt::ClipOperation op)
+void QPainter_setClipRect2(QPainterH handle, PRect AnonParam1, Qt::ClipOperation op)
 {
-	QRect t_p1;
-	copyPRectToQRect(p1, t_p1);
-	((QPainter *)handle)->setClipRect(t_p1, op);
+	QRect t_AnonParam1;
+	copyPRectToQRect(AnonParam1, t_AnonParam1);
+	((QPainter *)handle)->setClipRect(t_AnonParam1, op);
 }
 
 void QPainter_setClipRect3(QPainterH handle, int x, int y, int w, int h, Qt::ClipOperation op)
@@ -193,9 +193,9 @@ void QPainter_setClipRect3(QPainterH handle, int x, int y, int w, int h, Qt::Cli
 	((QPainter *)handle)->setClipRect(x, y, w, h, op);
 }
 
-void QPainter_setClipRegion(QPainterH handle, const QRegionH p1, Qt::ClipOperation op)
+void QPainter_setClipRegion(QPainterH handle, const QRegionH AnonParam1, Qt::ClipOperation op)
 {
-	((QPainter *)handle)->setClipRegion(*(const QRegion*)p1, op);
+	((QPainter *)handle)->setClipRegion(*(const QRegion*)AnonParam1, op);
 }
 
 void QPainter_setClipPath(QPainterH handle, const QPainterPathH path, Qt::ClipOperation op)
@@ -608,11 +608,11 @@ void QPainter_drawArc(QPainterH handle, const QRectFH rect, int a, int alen)
 	((QPainter *)handle)->drawArc(*(const QRectF*)rect, a, alen);
 }
 
-void QPainter_drawArc2(QPainterH handle, PRect p1, int a, int alen)
+void QPainter_drawArc2(QPainterH handle, PRect AnonParam1, int a, int alen)
 {
-	QRect t_p1;
-	copyPRectToQRect(p1, t_p1);
-	((QPainter *)handle)->drawArc(t_p1, a, alen);
+	QRect t_AnonParam1;
+	copyPRectToQRect(AnonParam1, t_AnonParam1);
+	((QPainter *)handle)->drawArc(t_AnonParam1, a, alen);
 }
 
 void QPainter_drawArc3(QPainterH handle, int x, int y, int w, int h, int a, int alen)
@@ -630,11 +630,11 @@ void QPainter_drawPie2(QPainterH handle, int x, int y, int w, int h, int a, int
 	((QPainter *)handle)->drawPie(x, y, w, h, a, alen);
 }
 
-void QPainter_drawPie3(QPainterH handle, PRect p1, int a, int alen)
+void QPainter_drawPie3(QPainterH handle, PRect AnonParam1, int a, int alen)
 {
-	QRect t_p1;
-	copyPRectToQRect(p1, t_p1);
-	((QPainter *)handle)->drawPie(t_p1, a, alen);
+	QRect t_AnonParam1;
+	copyPRectToQRect(AnonParam1, t_AnonParam1);
+	((QPainter *)handle)->drawPie(t_AnonParam1, a, alen);
 }
 
 void QPainter_drawChord(QPainterH handle, const QRectFH rect, int a, int alen)
@@ -647,11 +647,11 @@ void QPainter_drawChord2(QPainterH handle, int x, int y, int w, int h, int a, in
 	((QPainter *)handle)->drawChord(x, y, w, h, a, alen);
 }
 
-void QPainter_drawChord3(QPainterH handle, PRect p1, int a, int alen)
+void QPainter_drawChord3(QPainterH handle, PRect AnonParam1, int a, int alen)
 {
-	QRect t_p1;
-	copyPRectToQRect(p1, t_p1);
-	((QPainter *)handle)->drawChord(t_p1, a, alen);
+	QRect t_AnonParam1;
+	copyPRectToQRect(AnonParam1, t_AnonParam1);
+	((QPainter *)handle)->drawChord(t_AnonParam1, a, alen);
 }
 
 void QPainter_drawRoundedRect(QPainterH handle, const QRectFH rect, qreal xRadius, qreal yRadius, Qt::SizeMode mode)
@@ -676,9 +676,9 @@ void QPainter_drawRoundRect(QPainterH handle, const QRectFH r, int xround, int y
 	((QPainter *)handle)->drawRoundRect(*(const QRectF*)r, xround, yround);
 }
 
-void QPainter_drawRoundRect2(QPainterH handle, int x, int y, int w, int h, int p5, int p6)
+void QPainter_drawRoundRect2(QPainterH handle, int x, int y, int w, int h, int AnonParam5, int AnonParam6)
 {
-	((QPainter *)handle)->drawRoundRect(x, y, w, h, p5, p6);
+	((QPainter *)handle)->drawRoundRect(x, y, w, h, AnonParam5, AnonParam6);
 }
 
 void QPainter_drawRoundRect3(QPainterH handle, PRect r, int xround, int yround)
@@ -693,16 +693,16 @@ void QPainter_drawTiledPixmap(QPainterH handle, const QRectFH rect, const QPixma
 	((QPainter *)handle)->drawTiledPixmap(*(const QRectF*)rect, *(const QPixmap*)pm, *(const QPointF*)offset);
 }
 
-void QPainter_drawTiledPixmap2(QPainterH handle, int x, int y, int w, int h, const QPixmapH p5, int sx, int sy)
+void QPainter_drawTiledPixmap2(QPainterH handle, int x, int y, int w, int h, const QPixmapH AnonParam5, int sx, int sy)
 {
-	((QPainter *)handle)->drawTiledPixmap(x, y, w, h, *(const QPixmap*)p5, sx, sy);
+	((QPainter *)handle)->drawTiledPixmap(x, y, w, h, *(const QPixmap*)AnonParam5, sx, sy);
 }
 
-void QPainter_drawTiledPixmap3(QPainterH handle, PRect p1, const QPixmapH p2, const QPointH p3)
+void QPainter_drawTiledPixmap3(QPainterH handle, PRect AnonParam1, const QPixmapH AnonParam2, const QPointH AnonParam3)
 {
-	QRect t_p1;
-	copyPRectToQRect(p1, t_p1);
-	((QPainter *)handle)->drawTiledPixmap(t_p1, *(const QPixmap*)p2, *(const QPoint*)p3);
+	QRect t_AnonParam1;
+	copyPRectToQRect(AnonParam1, t_AnonParam1);
+	((QPainter *)handle)->drawTiledPixmap(t_AnonParam1, *(const QPixmap*)AnonParam2, *(const QPoint*)AnonParam3);
 }
 
 void QPainter_drawPicture(QPainterH handle, const QPointFH p, const QPictureH picture)
@@ -948,26 +948,26 @@ void QPainter_boundingRect4(QPainterH handle, QRectFH retval, const QRectFH rect
 	*(QRectF *)retval = ((QPainter *)handle)->boundingRect(*(const QRectF*)rect, t_text, *(const QTextOption*)o);
 }
 
-void QPainter_fillRect(QPainterH handle, const QRectFH p1, const QBrushH p2)
+void QPainter_fillRect(QPainterH handle, const QRectFH AnonParam1, const QBrushH AnonParam2)
 {
-	((QPainter *)handle)->fillRect(*(const QRectF*)p1, *(const QBrush*)p2);
+	((QPainter *)handle)->fillRect(*(const QRectF*)AnonParam1, *(const QBrush*)AnonParam2);
 }
 
-void QPainter_fillRect2(QPainterH handle, int x, int y, int w, int h, const QBrushH p5)
+void QPainter_fillRect2(QPainterH handle, int x, int y, int w, int h, const QBrushH AnonParam5)
 {
-	((QPainter *)handle)->fillRect(x, y, w, h, *(const QBrush*)p5);
+	((QPainter *)handle)->fillRect(x, y, w, h, *(const QBrush*)AnonParam5);
 }
 
-void QPainter_fillRect3(QPainterH handle, PRect p1, const QBrushH p2)
+void QPainter_fillRect3(QPainterH handle, PRect AnonParam1, const QBrushH AnonParam2)
 {
-	QRect t_p1;
-	copyPRectToQRect(p1, t_p1);
-	((QPainter *)handle)->fillRect(t_p1, *(const QBrush*)p2);
+	QRect t_AnonParam1;
+	copyPRectToQRect(AnonParam1, t_AnonParam1);
+	((QPainter *)handle)->fillRect(t_AnonParam1, *(const QBrush*)AnonParam2);
 }
 
-void QPainter_fillRect4(QPainterH handle, const QRectFH p1, const QColorH color)
+void QPainter_fillRect4(QPainterH handle, const QRectFH AnonParam1, const QColorH color)
 {
-	((QPainter *)handle)->fillRect(*(const QRectF*)p1, *(const QColor*)color);
+	((QPainter *)handle)->fillRect(*(const QRectF*)AnonParam1, *(const QColor*)color);
 }
 
 void QPainter_fillRect5(QPainterH handle, int x, int y, int w, int h, const QColorH color)
@@ -975,11 +975,11 @@ void QPainter_fillRect5(QPainterH handle, int x, int y, int w, int h, const QCol
 	((QPainter *)handle)->fillRect(x, y, w, h, *(const QColor*)color);
 }
 
-void QPainter_fillRect6(QPainterH handle, PRect p1, const QColorH color)
+void QPainter_fillRect6(QPainterH handle, PRect AnonParam1, const QColorH color)
 {
-	QRect t_p1;
-	copyPRectToQRect(p1, t_p1);
-	((QPainter *)handle)->fillRect(t_p1, *(const QColor*)color);
+	QRect t_AnonParam1;
+	copyPRectToQRect(AnonParam1, t_AnonParam1);
+	((QPainter *)handle)->fillRect(t_AnonParam1, *(const QColor*)color);
 }
 
 void QPainter_fillRect7(QPainterH handle, int x, int y, int w, int h, Qt::GlobalColor c)
@@ -1016,9 +1016,9 @@ void QPainter_fillRect12(QPainterH handle, const QRectFH r, Qt::BrushStyle style
 	((QPainter *)handle)->fillRect(*(const QRectF*)r, style);
 }
 
-void QPainter_eraseRect(QPainterH handle, const QRectFH p1)
+void QPainter_eraseRect(QPainterH handle, const QRectFH AnonParam1)
 {
-	((QPainter *)handle)->eraseRect(*(const QRectF*)p1);
+	((QPainter *)handle)->eraseRect(*(const QRectF*)AnonParam1);
 }
 
 void QPainter_eraseRect2(QPainterH handle, int x, int y, int w, int h)
@@ -1026,11 +1026,11 @@ void QPainter_eraseRect2(QPainterH handle, int x, int y, int w, int h)
 	((QPainter *)handle)->eraseRect(x, y, w, h);
 }
 
-void QPainter_eraseRect3(QPainterH handle, PRect p1)
+void QPainter_eraseRect3(QPainterH handle, PRect AnonParam1)
 {
-	QRect t_p1;
-	copyPRectToQRect(p1, t_p1);
-	((QPainter *)handle)->eraseRect(t_p1);
+	QRect t_AnonParam1;
+	copyPRectToQRect(AnonParam1, t_AnonParam1);
+	((QPainter *)handle)->eraseRect(t_AnonParam1);
 }
 
 void QPainter_setRenderHint(QPainterH handle, QPainter::RenderHint hint, bool on)
