@@ -17,9 +17,9 @@
 
 C_EXPORT QPainterH QPainter_create();
 C_EXPORT void QPainter_destroy(QPainterH handle);
-C_EXPORT QPainterH QPainter_create2(QPaintDeviceH p1);
+C_EXPORT QPainterH QPainter_create2(QPaintDeviceH AnonParam1);
 C_EXPORT QPaintDeviceH QPainter_device(QPainterH handle);
-C_EXPORT bool QPainter_begin(QPainterH handle, QPaintDeviceH p1);
+C_EXPORT bool QPainter_begin(QPainterH handle, QPaintDeviceH AnonParam1);
 C_EXPORT bool QPainter_end(QPainterH handle);
 C_EXPORT bool QPainter_isActive(QPainterH handle);
 C_EXPORT void QPainter_initFrom(QPainterH handle, const QWidgetH widget);
@@ -40,18 +40,18 @@ C_EXPORT void QPainter_setBackgroundMode(QPainterH handle, Qt::BGMode mode);
 C_EXPORT Qt::BGMode QPainter_backgroundMode(QPainterH handle);
 C_EXPORT void QPainter_brushOrigin(QPainterH handle, PQtPoint retval);
 C_EXPORT void QPainter_setBrushOrigin(QPainterH handle, int x, int y);
-C_EXPORT void QPainter_setBrushOrigin2(QPainterH handle, const QPointH p1);
-C_EXPORT void QPainter_setBrushOrigin3(QPainterH handle, const QPointFH p1);
+C_EXPORT void QPainter_setBrushOrigin2(QPainterH handle, const QPointH AnonParam1);
+C_EXPORT void QPainter_setBrushOrigin3(QPainterH handle, const QPointFH AnonParam1);
 C_EXPORT void QPainter_setBackground(QPainterH handle, const QBrushH bg);
 C_EXPORT const QBrushH QPainter_background(QPainterH handle);
 C_EXPORT qreal QPainter_opacity(QPainterH handle);
 C_EXPORT void QPainter_setOpacity(QPainterH handle, qreal opacity);
 C_EXPORT void QPainter_clipRegion(QPainterH handle, QRegionH retval);
 C_EXPORT void QPainter_clipPath(QPainterH handle, QPainterPathH retval);
-C_EXPORT void QPainter_setClipRect(QPainterH handle, const QRectFH p1, Qt::ClipOperation op);
-C_EXPORT void QPainter_setClipRect2(QPainterH handle, PRect p1, Qt::ClipOperation op);
+C_EXPORT void QPainter_setClipRect(QPainterH handle, const QRectFH AnonParam1, Qt::ClipOperation op);
+C_EXPORT void QPainter_setClipRect2(QPainterH handle, PRect AnonParam1, Qt::ClipOperation op);
 C_EXPORT void QPainter_setClipRect3(QPainterH handle, int x, int y, int w, int h, Qt::ClipOperation op);
-C_EXPORT void QPainter_setClipRegion(QPainterH handle, const QRegionH p1, Qt::ClipOperation op);
+C_EXPORT void QPainter_setClipRegion(QPainterH handle, const QRegionH AnonParam1, Qt::ClipOperation op);
 C_EXPORT void QPainter_setClipPath(QPainterH handle, const QPainterPathH path, Qt::ClipOperation op);
 C_EXPORT void QPainter_setClipping(QPainterH handle, bool enable);
 C_EXPORT bool QPainter_hasClipping(QPainterH handle);
@@ -131,23 +131,23 @@ C_EXPORT void QPainter_drawConvexPolygon2(QPainterH handle, const QPolygonFH pol
 C_EXPORT void QPainter_drawConvexPolygon3(QPainterH handle, const QPointH points, int pointCount);
 C_EXPORT void QPainter_drawConvexPolygon4(QPainterH handle, const QPolygonH polygon);
 C_EXPORT void QPainter_drawArc(QPainterH handle, const QRectFH rect, int a, int alen);
-C_EXPORT void QPainter_drawArc2(QPainterH handle, PRect p1, int a, int alen);
+C_EXPORT void QPainter_drawArc2(QPainterH handle, PRect AnonParam1, int a, int alen);
 C_EXPORT void QPainter_drawArc3(QPainterH handle, int x, int y, int w, int h, int a, int alen);
 C_EXPORT void QPainter_drawPie(QPainterH handle, const QRectFH rect, int a, int alen);
 C_EXPORT void QPainter_drawPie2(QPainterH handle, int x, int y, int w, int h, int a, int alen);
-C_EXPORT void QPainter_drawPie3(QPainterH handle, PRect p1, int a, int alen);
+C_EXPORT void QPainter_drawPie3(QPainterH handle, PRect AnonParam1, int a, int alen);
 C_EXPORT void QPainter_drawChord(QPainterH handle, const QRectFH rect, int a, int alen);
 C_EXPORT void QPainter_drawChord2(QPainterH handle, int x, int y, int w, int h, int a, int alen);
-C_EXPORT void QPainter_drawChord3(QPainterH handle, PRect p1, int a, int alen);
+C_EXPORT void QPainter_drawChord3(QPainterH handle, PRect AnonParam1, int a, int alen);
 C_EXPORT void QPainter_drawRoundedRect(QPainterH handle, const QRectFH rect, qreal xRadius, qreal yRadius, Qt::SizeMode mode);
 C_EXPORT void QPainter_drawRoundedRect2(QPainterH handle, int x, int y, int w, int h, qreal xRadius, qreal yRadius, Qt::SizeMode mode);
 C_EXPORT void QPainter_drawRoundedRect3(QPainterH handle, PRect rect, qreal xRadius, qreal yRadius, Qt::SizeMode mode);
 C_EXPORT void QPainter_drawRoundRect(QPainterH handle, const QRectFH r, int xround, int yround);
-C_EXPORT void QPainter_drawRoundRect2(QPainterH handle, int x, int y, int w, int h, int p5, int p6);
+C_EXPORT void QPainter_drawRoundRect2(QPainterH handle, int x, int y, int w, int h, int AnonParam5, int AnonParam6);
 C_EXPORT void QPainter_drawRoundRect3(QPainterH handle, PRect r, int xround, int yround);
 C_EXPORT void QPainter_drawTiledPixmap(QPainterH handle, const QRectFH rect, const QPixmapH pm, const QPointFH offset);
-C_EXPORT void QPainter_drawTiledPixmap2(QPainterH handle, int x, int y, int w, int h, const QPixmapH p5, int sx, int sy);
-C_EXPORT void QPainter_drawTiledPixmap3(QPainterH handle, PRect p1, const QPixmapH p2, const QPointH p3);
+C_EXPORT void QPainter_drawTiledPixmap2(QPainterH handle, int x, int y, int w, int h, const QPixmapH AnonParam5, int sx, int sy);
+C_EXPORT void QPainter_drawTiledPixmap3(QPainterH handle, PRect AnonParam1, const QPixmapH AnonParam2, const QPointH AnonParam3);
 C_EXPORT void QPainter_drawPicture(QPainterH handle, const QPointFH p, const QPictureH picture);
 C_EXPORT void QPainter_drawPicture2(QPainterH handle, int x, int y, const QPictureH picture);
 C_EXPORT void QPainter_drawPicture3(QPainterH handle, const QPointH p, const QPictureH picture);
@@ -185,21 +185,21 @@ C_EXPORT void QPainter_boundingRect(QPainterH handle, QRectFH retval, const QRec
 C_EXPORT void QPainter_boundingRect2(QPainterH handle, PRect retval, PRect rect, int flags, PWideString text);
 C_EXPORT void QPainter_boundingRect3(QPainterH handle, PRect retval, int x, int y, int w, int h, int flags, PWideString text);
 C_EXPORT void QPainter_boundingRect4(QPainterH handle, QRectFH retval, const QRectFH rect, PWideString text, const QTextOptionH o);
-C_EXPORT void QPainter_fillRect(QPainterH handle, const QRectFH p1, const QBrushH p2);
-C_EXPORT void QPainter_fillRect2(QPainterH handle, int x, int y, int w, int h, const QBrushH p5);
-C_EXPORT void QPainter_fillRect3(QPainterH handle, PRect p1, const QBrushH p2);
-C_EXPORT void QPainter_fillRect4(QPainterH handle, const QRectFH p1, const QColorH color);
+C_EXPORT void QPainter_fillRect(QPainterH handle, const QRectFH AnonParam1, const QBrushH AnonParam2);
+C_EXPORT void QPainter_fillRect2(QPainterH handle, int x, int y, int w, int h, const QBrushH AnonParam5);
+C_EXPORT void QPainter_fillRect3(QPainterH handle, PRect AnonParam1, const QBrushH AnonParam2);
+C_EXPORT void QPainter_fillRect4(QPainterH handle, const QRectFH AnonParam1, const QColorH color);
 C_EXPORT void QPainter_fillRect5(QPainterH handle, int x, int y, int w, int h, const QColorH color);
-C_EXPORT void QPainter_fillRect6(QPainterH handle, PRect p1, const QColorH color);
+C_EXPORT void QPainter_fillRect6(QPainterH handle, PRect AnonParam1, const QColorH color);
 C_EXPORT void QPainter_fillRect7(QPainterH handle, int x, int y, int w, int h, Qt::GlobalColor c);
 C_EXPORT void QPainter_fillRect8(QPainterH handle, PRect r, Qt::GlobalColor c);
 C_EXPORT void QPainter_fillRect9(QPainterH handle, const QRectFH r, Qt::GlobalColor c);
 C_EXPORT void QPainter_fillRect10(QPainterH handle, int x, int y, int w, int h, Qt::BrushStyle style);
 C_EXPORT void QPainter_fillRect11(QPainterH handle, PRect r, Qt::BrushStyle style);
 C_EXPORT void QPainter_fillRect12(QPainterH handle, const QRectFH r, Qt::BrushStyle style);
-C_EXPORT void QPainter_eraseRect(QPainterH handle, const QRectFH p1);
+C_EXPORT void QPainter_eraseRect(QPainterH handle, const QRectFH AnonParam1);
 C_EXPORT void QPainter_eraseRect2(QPainterH handle, int x, int y, int w, int h);
-C_EXPORT void QPainter_eraseRect3(QPainterH handle, PRect p1);
+C_EXPORT void QPainter_eraseRect3(QPainterH handle, PRect AnonParam1);
 C_EXPORT void QPainter_setRenderHint(QPainterH handle, QPainter::RenderHint hint, bool on);
 C_EXPORT void QPainter_setRenderHints(QPainterH handle, unsigned int hints, bool on);
 C_EXPORT unsigned int QPainter_renderHints(QPainterH handle);
