@@ -15,7 +15,7 @@
 #include <QtGui>
 #include "pascalbind.h"
 
-C_EXPORT QRubberBandH QRubberBand_create(QRubberBand::Shape p1, QWidgetH p2);
+C_EXPORT QRubberBandH QRubberBand_create(QRubberBand::Shape AnonParam1, QWidgetH AnonParam2);
 C_EXPORT void QRubberBand_destroy(QRubberBandH handle);
 C_EXPORT QRubberBand::Shape QRubberBand_shape(QRubberBandH handle);
 C_EXPORT void QRubberBand_setGeometry(QRubberBandH handle, PRect r);
