@@ -21,9 +21,9 @@ void QScrollBar_destroy(QScrollBarH handle)
 	delete (QScrollBar *)handle;
 }
 
-QScrollBarH QScrollBar_create2(Qt::Orientation p1, QWidgetH parent)
+QScrollBarH QScrollBar_create2(Qt::Orientation AnonParam1, QWidgetH parent)
 {
-	return (QScrollBarH) new QScrollBar(p1, (QWidget*)parent);
+	return (QScrollBarH) new QScrollBar(AnonParam1, (QWidget*)parent);
 }
 
 void QScrollBar_sizeHint(QScrollBarH handle, PSize retval)
