@@ -17,7 +17,7 @@
 
 C_EXPORT QScrollBarH QScrollBar_create(QWidgetH parent);
 C_EXPORT void QScrollBar_destroy(QScrollBarH handle);
-C_EXPORT QScrollBarH QScrollBar_create2(Qt::Orientation p1, QWidgetH parent);
+C_EXPORT QScrollBarH QScrollBar_create2(Qt::Orientation AnonParam1, QWidgetH parent);
 C_EXPORT void QScrollBar_sizeHint(QScrollBarH handle, PSize retval);
 C_EXPORT bool QScrollBar_event(QScrollBarH handle, QEventH event);
 
