@@ -26,8 +26,8 @@ void QSizeGrip_sizeHint(QSizeGripH handle, PSize retval)
 	*(QSize *)retval = ((QSizeGrip *)handle)->sizeHint();
 }
 
-void QSizeGrip_setVisible(QSizeGripH handle, bool p1)
+void QSizeGrip_setVisible(QSizeGripH handle, bool AnonParam1)
 {
-	((QSizeGrip *)handle)->setVisible(p1);
+	((QSizeGrip *)handle)->setVisible(AnonParam1);
 }
 
