@@ -18,6 +18,6 @@
 C_EXPORT QSizeGripH QSizeGrip_create(QWidgetH parent);
 C_EXPORT void QSizeGrip_destroy(QSizeGripH handle);
 C_EXPORT void QSizeGrip_sizeHint(QSizeGripH handle, PSize retval);
-C_EXPORT void QSizeGrip_setVisible(QSizeGripH handle, bool p1);
+C_EXPORT void QSizeGrip_setVisible(QSizeGripH handle, bool AnonParam1);
 
 #endif
