@@ -11,9 +11,9 @@
 
 #include "qsocketnotifier_c.h"
 
-QSocketNotifierH QSocketNotifier_create(int socket, QSocketNotifier::Type p2, QObjectH parent)
+QSocketNotifierH QSocketNotifier_create(int socket, QSocketNotifier::Type AnonParam2, QObjectH parent)
 {
-	return (QSocketNotifierH) new QSocketNotifier(socket, p2, (QObject*)parent);
+	return (QSocketNotifierH) new QSocketNotifier(socket, AnonParam2, (QObject*)parent);
 }
 
 void QSocketNotifier_destroy(QSocketNotifierH handle)
@@ -36,8 +36,8 @@ bool QSocketNotifier_isEnabled(QSocketNotifierH handle)
 	return (bool) ((QSocketNotifier *)handle)->isEnabled();
 }
 
-void QSocketNotifier_setEnabled(QSocketNotifierH handle, bool p1)
+void QSocketNotifier_setEnabled(QSocketNotifierH handle, bool AnonParam1)
 {
-	((QSocketNotifier *)handle)->setEnabled(p1);
+	((QSocketNotifier *)handle)->setEnabled(AnonParam1);
 }
 
