@@ -15,11 +15,11 @@
 #include <QtCore>
 #include "pascalbind.h"
 
-C_EXPORT QSocketNotifierH QSocketNotifier_create(int socket, QSocketNotifier::Type p2, QObjectH parent);
+C_EXPORT QSocketNotifierH QSocketNotifier_create(int socket, QSocketNotifier::Type AnonParam2, QObjectH parent);
 C_EXPORT void QSocketNotifier_destroy(QSocketNotifierH handle);
 C_EXPORT int QSocketNotifier_socket(QSocketNotifierH handle);
 C_EXPORT QSocketNotifier::Type QSocketNotifier_type(QSocketNotifierH handle);
 C_EXPORT bool QSocketNotifier_isEnabled(QSocketNotifierH handle);
-C_EXPORT void QSocketNotifier_setEnabled(QSocketNotifierH handle, bool p1);
+C_EXPORT void QSocketNotifier_setEnabled(QSocketNotifierH handle, bool AnonParam1);
 
 #endif
