@@ -22,8 +22,8 @@ C_EXPORT int QStackedWidget_insertWidget(QStackedWidgetH handle, int index, QWid
 C_EXPORT void QStackedWidget_removeWidget(QStackedWidgetH handle, QWidgetH w);
 C_EXPORT QWidgetH QStackedWidget_currentWidget(QStackedWidgetH handle);
 C_EXPORT int QStackedWidget_currentIndex(QStackedWidgetH handle);
-C_EXPORT int QStackedWidget_indexOf(QStackedWidgetH handle, QWidgetH p1);
-C_EXPORT QWidgetH QStackedWidget_widget(QStackedWidgetH handle, int p1);
+C_EXPORT int QStackedWidget_indexOf(QStackedWidgetH handle, QWidgetH AnonParam1);
+C_EXPORT QWidgetH QStackedWidget_widget(QStackedWidgetH handle, int AnonParam1);
 C_EXPORT int QStackedWidget_count(QStackedWidgetH handle);
 C_EXPORT void QStackedWidget_setCurrentIndex(QStackedWidgetH handle, int index);
 C_EXPORT void QStackedWidget_setCurrentWidget(QStackedWidgetH handle, QWidgetH w);
