@@ -36,11 +36,11 @@ QStringH QString_create5(const QLatin1StringH latin1)
 	return (QStringH) new QString(*(const QLatin1String*)latin1);
 }
 
-QStringH QString_create6(PWideString p1)
+QStringH QString_create6(PWideString AnonParam1)
 {
-	QString t_p1;
-	copyPWideStringToQString(p1, t_p1);
-	return (QStringH) new QString(t_p1);
+	QString t_AnonParam1;
+	copyPWideStringToQString(AnonParam1, t_AnonParam1);
+	return (QStringH) new QString(t_AnonParam1);
 }
 
 int QString_size(QStringH handle)
@@ -402,14 +402,14 @@ int QString_count3(QStringH handle, PWideString s, Qt::CaseSensitivity cs)
 	return (int) ((QString *)handle)->count(t_s, cs);
 }
 
-int QString_indexOf4(QStringH handle, const QRegExpH p1, int from)
+int QString_indexOf4(QStringH handle, const QRegExpH AnonParam1, int from)
 {
-	return (int) ((QString *)handle)->indexOf(*(const QRegExp*)p1, from);
+	return (int) ((QString *)handle)->indexOf(*(const QRegExp*)AnonParam1, from);
 }
 
-int QString_lastIndexOf4(QStringH handle, const QRegExpH p1, int from)
+int QString_lastIndexOf4(QStringH handle, const QRegExpH AnonParam1, int from)
 {
-	return (int) ((QString *)handle)->lastIndexOf(*(const QRegExp*)p1, from);
+	return (int) ((QString *)handle)->lastIndexOf(*(const QRegExp*)AnonParam1, from);
 }
 
 QBool QString_contains3(QStringH handle, const QRegExpH rx)
@@ -417,9 +417,9 @@ QBool QString_contains3(QStringH handle, const QRegExpH rx)
 	return (QBool) ((QString *)handle)->contains(*(const QRegExp*)rx);
 }
 
-int QString_count4(QStringH handle, const QRegExpH p1)
+int QString_count4(QStringH handle, const QRegExpH AnonParam1)
 {
-	return (int) ((QString *)handle)->count(*(const QRegExp*)p1);
+	return (int) ((QString *)handle)->count(*(const QRegExp*)AnonParam1);
 }
 
 void QString_section(QStringH handle, PWideString retval, PWideChar sep, int start, int end, unsigned int flags)
@@ -816,52 +816,52 @@ void QString_toLocal8Bit(QStringH handle, QByteArrayH retval)
 	*(QByteArray *)retval = ((QString *)handle)->toLocal8Bit();
 }
 
-void QString_fromAscii(PWideString retval, const char* p1, int size)
+void QString_fromAscii(PWideString retval, const char* AnonParam1, int size)
 {
 	QString t_retval;
-	t_retval = QString::fromAscii(p1, size);
+	t_retval = QString::fromAscii(AnonParam1, size);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_fromLatin1(PWideString retval, const char* p1, int size)
+void QString_fromLatin1(PWideString retval, const char* AnonParam1, int size)
 {
 	QString t_retval;
-	t_retval = QString::fromLatin1(p1, size);
+	t_retval = QString::fromLatin1(AnonParam1, size);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_fromUtf8(PWideString retval, const char* p1, int size)
+void QString_fromUtf8(PWideString retval, const char* AnonParam1, int size)
 {
 	QString t_retval;
-	t_retval = QString::fromUtf8(p1, size);
+	t_retval = QString::fromUtf8(AnonParam1, size);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_fromLocal8Bit(PWideString retval, const char* p1, int size)
+void QString_fromLocal8Bit(PWideString retval, const char* AnonParam1, int size)
 {
 	QString t_retval;
-	t_retval = QString::fromLocal8Bit(p1, size);
+	t_retval = QString::fromLocal8Bit(AnonParam1, size);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_fromUtf16(PWideString retval, const ushort* p1, int size)
+void QString_fromUtf16(PWideString retval, const ushort* AnonParam1, int size)
 {
 	QString t_retval;
-	t_retval = QString::fromUtf16(p1, size);
+	t_retval = QString::fromUtf16(AnonParam1, size);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_fromUcs4(PWideString retval, const uint* p1, int size)
+void QString_fromUcs4(PWideString retval, const uint* AnonParam1, int size)
 {
 	QString t_retval;
-	t_retval = QString::fromUcs4(p1, size);
+	t_retval = QString::fromUcs4(AnonParam1, size);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_fromRawData(PWideString retval, const QCharH p1, int size)
+void QString_fromRawData(PWideString retval, const QCharH AnonParam1, int size)
 {
 	QString t_retval;
-	t_retval = QString::fromRawData((const QChar*)p1, size);
+	t_retval = QString::fromRawData((const QChar*)AnonParam1, size);
 	copyQStringToPWideString(t_retval, retval);
 }
 
@@ -870,10 +870,10 @@ int QString_toWCharArray(QStringH handle, wchar_t* array)
 	return (int) ((QString *)handle)->toWCharArray(array);
 }
 
-void QString_fromWCharArray(PWideString retval, const wchar_t* p1, int size)
+void QString_fromWCharArray(PWideString retval, const wchar_t* AnonParam1, int size)
 {
 	QString t_retval;
-	t_retval = QString::fromWCharArray(p1, size);
+	t_retval = QString::fromWCharArray(AnonParam1, size);
 	copyQStringToPWideString(t_retval, retval);
 }
 
@@ -1008,94 +1008,94 @@ double QString_toDouble(QStringH handle, bool* ok)
 	return (double) ((QString *)handle)->toDouble(ok);
 }
 
-void QString_setNum(QStringH handle, PWideString retval, short p1, int base)
+void QString_setNum(QStringH handle, PWideString retval, short AnonParam1, int base)
 {
 	QString t_retval;
-	t_retval = ((QString *)handle)->setNum(p1, base);
+	t_retval = ((QString *)handle)->setNum(AnonParam1, base);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_setNum2(QStringH handle, PWideString retval, ushort p1, int base)
+void QString_setNum2(QStringH handle, PWideString retval, ushort AnonParam1, int base)
 {
 	QString t_retval;
-	t_retval = ((QString *)handle)->setNum(p1, base);
+	t_retval = ((QString *)handle)->setNum(AnonParam1, base);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_setNum3(QStringH handle, PWideString retval, int p1, int base)
+void QString_setNum3(QStringH handle, PWideString retval, int AnonParam1, int base)
 {
 	QString t_retval;
-	t_retval = ((QString *)handle)->setNum(p1, base);
+	t_retval = ((QString *)handle)->setNum(AnonParam1, base);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_setNum4(QStringH handle, PWideString retval, uint p1, int base)
+void QString_setNum4(QStringH handle, PWideString retval, uint AnonParam1, int base)
 {
 	QString t_retval;
-	t_retval = ((QString *)handle)->setNum(p1, base);
+	t_retval = ((QString *)handle)->setNum(AnonParam1, base);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_setNum7(QStringH handle, PWideString retval, qlonglong p1, int base)
+void QString_setNum7(QStringH handle, PWideString retval, qlonglong AnonParam1, int base)
 {
 	QString t_retval;
-	t_retval = ((QString *)handle)->setNum(p1, base);
+	t_retval = ((QString *)handle)->setNum(AnonParam1, base);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_setNum8(QStringH handle, PWideString retval, qulonglong p1, int base)
+void QString_setNum8(QStringH handle, PWideString retval, qulonglong AnonParam1, int base)
 {
 	QString t_retval;
-	t_retval = ((QString *)handle)->setNum(p1, base);
+	t_retval = ((QString *)handle)->setNum(AnonParam1, base);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_setNum9(QStringH handle, PWideString retval, float p1, char f, int prec)
+void QString_setNum9(QStringH handle, PWideString retval, float AnonParam1, char f, int prec)
 {
 	QString t_retval;
-	t_retval = ((QString *)handle)->setNum(p1, f, prec);
+	t_retval = ((QString *)handle)->setNum(AnonParam1, f, prec);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_setNum10(QStringH handle, PWideString retval, double p1, char f, int prec)
+void QString_setNum10(QStringH handle, PWideString retval, double AnonParam1, char f, int prec)
 {
 	QString t_retval;
-	t_retval = ((QString *)handle)->setNum(p1, f, prec);
+	t_retval = ((QString *)handle)->setNum(AnonParam1, f, prec);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_number(PWideString retval, int p1, int base)
+void QString_number(PWideString retval, int AnonParam1, int base)
 {
 	QString t_retval;
-	t_retval = QString::number(p1, base);
+	t_retval = QString::number(AnonParam1, base);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_number2(PWideString retval, uint p1, int base)
+void QString_number2(PWideString retval, uint AnonParam1, int base)
 {
 	QString t_retval;
-	t_retval = QString::number(p1, base);
+	t_retval = QString::number(AnonParam1, base);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_number5(PWideString retval, qlonglong p1, int base)
+void QString_number5(PWideString retval, qlonglong AnonParam1, int base)
 {
 	QString t_retval;
-	t_retval = QString::number(p1, base);
+	t_retval = QString::number(AnonParam1, base);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_number6(PWideString retval, qulonglong p1, int base)
+void QString_number6(PWideString retval, qulonglong AnonParam1, int base)
 {
 	QString t_retval;
-	t_retval = QString::number(p1, base);
+	t_retval = QString::number(AnonParam1, base);
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QString_number7(PWideString retval, double p1, char f, int prec)
+void QString_number7(PWideString retval, double AnonParam1, char f, int prec)
 {
 	QString t_retval;
-	t_retval = QString::number(p1, f, prec);
+	t_retval = QString::number(AnonParam1, f, prec);
 	copyQStringToPWideString(t_retval, retval);
 }
 
