@@ -16,6 +16,6 @@
 #include "pascalbind.h"
 
 C_EXPORT void QStyleFactory_keys(QStringListH retval);
-C_EXPORT QStyleH QStyleFactory_create(PWideString p1);
+C_EXPORT QStyleH QStyleFactory_create(PWideString AnonParam1);
 
 #endif
