@@ -28,7 +28,7 @@ C_EXPORT bool QThread_isRunning(QThreadH handle);
 C_EXPORT void QThread_setStackSize(QThreadH handle, uint stackSize);
 C_EXPORT uint QThread_stackSize(QThreadH handle);
 C_EXPORT void QThread_exit(QThreadH handle, int retcode);
-C_EXPORT void QThread_start(QThreadH handle, QThread::Priority p1);
+C_EXPORT void QThread_start(QThreadH handle, QThread::Priority AnonParam1);
 C_EXPORT void QThread_terminate(QThreadH handle);
 C_EXPORT void QThread_quit(QThreadH handle);
 C_EXPORT bool QThread_wait(QThreadH handle, unsigned long time);
