@@ -31,10 +31,10 @@ class QToolButton_hook : public QAbstractButton_hook {
     }
 
   private slots:
-    void triggered_hook(QAction* p1) {
+    void triggered_hook(QAction* AnonParam1) {
       if ( triggered_event.func ) {
-        typedef void (*func_type)(void *data, QActionH p1);
-	(*(func_type)triggered_event.func)(triggered_event.data, (QActionH)p1);
+        typedef void (*func_type)(void *data, QActionH AnonParam1);
+	(*(func_type)triggered_event.func)(triggered_event.data, (QActionH)AnonParam1);
       }
     }
   private:
