@@ -21,8 +21,8 @@ C_EXPORT void QToolTip_hideText();
 C_EXPORT bool QToolTip_isVisible();
 C_EXPORT void QToolTip_text(PWideString retval);
 C_EXPORT void QToolTip_palette(QPaletteH retval);
-C_EXPORT void QToolTip_setPalette(const QPaletteH p1);
+C_EXPORT void QToolTip_setPalette(const QPaletteH AnonParam1);
 C_EXPORT void QToolTip_font(QFontH retval);
-C_EXPORT void QToolTip_setFont(const QFontH p1);
+C_EXPORT void QToolTip_setFont(const QFontH AnonParam1);
 
 #endif
