@@ -51,9 +51,9 @@ QStyleH QWidget_style(QWidgetH handle)
 	return (QStyleH) ((QWidget *)handle)->style();
 }
 
-void QWidget_setStyle(QWidgetH handle, QStyleH p1)
+void QWidget_setStyle(QWidgetH handle, QStyleH AnonParam1)
 {
-	((QWidget *)handle)->setStyle((QStyle*)p1);
+	((QWidget *)handle)->setStyle((QStyle*)AnonParam1);
 }
 
 bool QWidget_isTopLevel(QWidgetH handle)
@@ -86,9 +86,9 @@ bool QWidget_isEnabled(QWidgetH handle)
 	return (bool) ((QWidget *)handle)->isEnabled();
 }
 
-bool QWidget_isEnabledTo(QWidgetH handle, QWidgetH p1)
+bool QWidget_isEnabledTo(QWidgetH handle, QWidgetH AnonParam1)
 {
-	return (bool) ((QWidget *)handle)->isEnabledTo((QWidget*)p1);
+	return (bool) ((QWidget *)handle)->isEnabledTo((QWidget*)AnonParam1);
 }
 
 bool QWidget_isEnabledToTLW(QWidgetH handle)
@@ -96,19 +96,19 @@ bool QWidget_isEnabledToTLW(QWidgetH handle)
 	return (bool) ((QWidget *)handle)->isEnabledToTLW();
 }
 
-void QWidget_setEnabled(QWidgetH handle, bool p1)
+void QWidget_setEnabled(QWidgetH handle, bool AnonParam1)
 {
-	((QWidget *)handle)->setEnabled(p1);
+	((QWidget *)handle)->setEnabled(AnonParam1);
 }
 
-void QWidget_setDisabled(QWidgetH handle, bool p1)
+void QWidget_setDisabled(QWidgetH handle, bool AnonParam1)
 {
-	((QWidget *)handle)->setDisabled(p1);
+	((QWidget *)handle)->setDisabled(AnonParam1);
 }
 
-void QWidget_setWindowModified(QWidgetH handle, bool p1)
+void QWidget_setWindowModified(QWidgetH handle, bool AnonParam1)
 {
-	((QWidget *)handle)->setWindowModified(p1);
+	((QWidget *)handle)->setWindowModified(AnonParam1);
 }
 
 void QWidget_frameGeometry(QWidgetH handle, PRect retval)
@@ -216,9 +216,9 @@ int QWidget_maximumHeight(QWidgetH handle)
 	return (int) ((QWidget *)handle)->maximumHeight();
 }
 
-void QWidget_setMinimumSize(QWidgetH handle, const QSizeH p1)
+void QWidget_setMinimumSize(QWidgetH handle, const QSizeH AnonParam1)
 {
-	((QWidget *)handle)->setMinimumSize(*(const QSize*)p1);
+	((QWidget *)handle)->setMinimumSize(*(const QSize*)AnonParam1);
 }
 
 void QWidget_setMinimumSize2(QWidgetH handle, int minw, int minh)
@@ -226,9 +226,9 @@ void QWidget_setMinimumSize2(QWidgetH handle, int minw, int minh)
 	((QWidget *)handle)->setMinimumSize(minw, minh);
 }
 
-void QWidget_setMaximumSize(QWidgetH handle, const QSizeH p1)
+void QWidget_setMaximumSize(QWidgetH handle, const QSizeH AnonParam1)
 {
-	((QWidget *)handle)->setMaximumSize(*(const QSize*)p1);
+	((QWidget *)handle)->setMaximumSize(*(const QSize*)AnonParam1);
 }
 
 void QWidget_setMaximumSize2(QWidgetH handle, int maxw, int maxh)
@@ -261,9 +261,9 @@ void QWidget_sizeIncrement(QWidgetH handle, PSize retval)
 	*(QSize *)retval = ((QWidget *)handle)->sizeIncrement();
 }
 
-void QWidget_setSizeIncrement(QWidgetH handle, const QSizeH p1)
+void QWidget_setSizeIncrement(QWidgetH handle, const QSizeH AnonParam1)
 {
-	((QWidget *)handle)->setSizeIncrement(*(const QSize*)p1);
+	((QWidget *)handle)->setSizeIncrement(*(const QSize*)AnonParam1);
 }
 
 void QWidget_setSizeIncrement2(QWidgetH handle, int w, int h)
@@ -276,9 +276,9 @@ void QWidget_baseSize(QWidgetH handle, PSize retval)
 	*(QSize *)retval = ((QWidget *)handle)->baseSize();
 }
 
-void QWidget_setBaseSize(QWidgetH handle, const QSizeH p1)
+void QWidget_setBaseSize(QWidgetH handle, const QSizeH AnonParam1)
 {
-	((QWidget *)handle)->setBaseSize(*(const QSize*)p1);
+	((QWidget *)handle)->setBaseSize(*(const QSize*)AnonParam1);
 }
 
 void QWidget_setBaseSize2(QWidgetH handle, int basew, int baseh)
@@ -286,9 +286,9 @@ void QWidget_setBaseSize2(QWidgetH handle, int basew, int baseh)
 	((QWidget *)handle)->setBaseSize(basew, baseh);
 }
 
-void QWidget_setFixedSize(QWidgetH handle, const QSizeH p1)
+void QWidget_setFixedSize(QWidgetH handle, const QSizeH AnonParam1)
 {
-	((QWidget *)handle)->setFixedSize(*(const QSize*)p1);
+	((QWidget *)handle)->setFixedSize(*(const QSize*)AnonParam1);
 }
 
 void QWidget_setFixedSize2(QWidgetH handle, int w, int h)
@@ -306,34 +306,34 @@ void QWidget_setFixedHeight(QWidgetH handle, int h)
 	((QWidget *)handle)->setFixedHeight(h);
 }
 
-void QWidget_mapToGlobal(QWidgetH handle, PQtPoint retval, const QPointH p1)
+void QWidget_mapToGlobal(QWidgetH handle, PQtPoint retval, const QPointH AnonParam1)
 {
-	*(QPoint *)retval = ((QWidget *)handle)->mapToGlobal(*(const QPoint*)p1);
+	*(QPoint *)retval = ((QWidget *)handle)->mapToGlobal(*(const QPoint*)AnonParam1);
 }
 
-void QWidget_mapFromGlobal(QWidgetH handle, PQtPoint retval, const QPointH p1)
+void QWidget_mapFromGlobal(QWidgetH handle, PQtPoint retval, const QPointH AnonParam1)
 {
-	*(QPoint *)retval = ((QWidget *)handle)->mapFromGlobal(*(const QPoint*)p1);
+	*(QPoint *)retval = ((QWidget *)handle)->mapFromGlobal(*(const QPoint*)AnonParam1);
 }
 
-void QWidget_mapToParent(QWidgetH handle, PQtPoint retval, const QPointH p1)
+void QWidget_mapToParent(QWidgetH handle, PQtPoint retval, const QPointH AnonParam1)
 {
-	*(QPoint *)retval = ((QWidget *)handle)->mapToParent(*(const QPoint*)p1);
+	*(QPoint *)retval = ((QWidget *)handle)->mapToParent(*(const QPoint*)AnonParam1);
 }
 
-void QWidget_mapFromParent(QWidgetH handle, PQtPoint retval, const QPointH p1)
+void QWidget_mapFromParent(QWidgetH handle, PQtPoint retval, const QPointH AnonParam1)
 {
-	*(QPoint *)retval = ((QWidget *)handle)->mapFromParent(*(const QPoint*)p1);
+	*(QPoint *)retval = ((QWidget *)handle)->mapFromParent(*(const QPoint*)AnonParam1);
 }
 
-void QWidget_mapTo(QWidgetH handle, PQtPoint retval, QWidgetH p1, const QPointH p2)
+void QWidget_mapTo(QWidgetH handle, PQtPoint retval, QWidgetH AnonParam1, const QPointH AnonParam2)
 {
-	*(QPoint *)retval = ((QWidget *)handle)->mapTo((QWidget*)p1, *(const QPoint*)p2);
+	*(QPoint *)retval = ((QWidget *)handle)->mapTo((QWidget*)AnonParam1, *(const QPoint*)AnonParam2);
 }
 
-void QWidget_mapFrom(QWidgetH handle, PQtPoint retval, QWidgetH p1, const QPointH p2)
+void QWidget_mapFrom(QWidgetH handle, PQtPoint retval, QWidgetH AnonParam1, const QPointH AnonParam2)
 {
-	*(QPoint *)retval = ((QWidget *)handle)->mapFrom((QWidget*)p1, *(const QPoint*)p2);
+	*(QPoint *)retval = ((QWidget *)handle)->mapFrom((QWidget*)AnonParam1, *(const QPoint*)AnonParam2);
 }
 
 QWidgetH QWidget_window(QWidgetH handle)
@@ -356,14 +356,14 @@ const QPaletteH QWidget_palette(QWidgetH handle)
 	return (const QPaletteH) &((QWidget *)handle)->palette();
 }
 
-void QWidget_setPalette(QWidgetH handle, const QPaletteH p1)
+void QWidget_setPalette(QWidgetH handle, const QPaletteH AnonParam1)
 {
-	((QWidget *)handle)->setPalette(*(const QPalette*)p1);
+	((QWidget *)handle)->setPalette(*(const QPalette*)AnonParam1);
 }
 
-void QWidget_setBackgroundRole(QWidgetH handle, QPalette::ColorRole p1)
+void QWidget_setBackgroundRole(QWidgetH handle, QPalette::ColorRole AnonParam1)
 {
-	((QWidget *)handle)->setBackgroundRole(p1);
+	((QWidget *)handle)->setBackgroundRole(AnonParam1);
 }
 
 QPalette::ColorRole QWidget_backgroundRole(QWidgetH handle)
@@ -371,9 +371,9 @@ QPalette::ColorRole QWidget_backgroundRole(QWidgetH handle)
 	return (QPalette::ColorRole) ((QWidget *)handle)->backgroundRole();
 }
 
-void QWidget_setForegroundRole(QWidgetH handle, QPalette::ColorRole p1)
+void QWidget_setForegroundRole(QWidgetH handle, QPalette::ColorRole AnonParam1)
 {
-	((QWidget *)handle)->setForegroundRole(p1);
+	((QWidget *)handle)->setForegroundRole(AnonParam1);
 }
 
 QPalette::ColorRole QWidget_foregroundRole(QWidgetH handle)
@@ -386,9 +386,9 @@ const QFontH QWidget_font(QWidgetH handle)
 	return (const QFontH) &((QWidget *)handle)->font();
 }
 
-void QWidget_setFont(QWidgetH handle, const QFontH p1)
+void QWidget_setFont(QWidgetH handle, const QFontH AnonParam1)
 {
-	((QWidget *)handle)->setFont(*(const QFont*)p1);
+	((QWidget *)handle)->setFont(*(const QFont*)AnonParam1);
 }
 
 void QWidget_fontMetrics(QWidgetH handle, QFontMetricsH retval)
@@ -406,9 +406,9 @@ void QWidget_cursor(QWidgetH handle, QCursorH retval)
 	*(QCursor *)retval = ((QWidget *)handle)->cursor();
 }
 
-void QWidget_setCursor(QWidgetH handle, const QCursorH p1)
+void QWidget_setCursor(QWidgetH handle, const QCursorH AnonParam1)
 {
-	((QWidget *)handle)->setCursor(*(const QCursor*)p1);
+	((QWidget *)handle)->setCursor(*(const QCursor*)AnonParam1);
 }
 
 void QWidget_unsetCursor(QWidgetH handle)
@@ -431,14 +431,14 @@ bool QWidget_underMouse(QWidgetH handle)
 	return (bool) ((QWidget *)handle)->underMouse();
 }
 
-void QWidget_setMask(QWidgetH handle, const QBitmapH p1)
+void QWidget_setMask(QWidgetH handle, const QBitmapH AnonParam1)
 {
-	((QWidget *)handle)->setMask(*(const QBitmap*)p1);
+	((QWidget *)handle)->setMask(*(const QBitmap*)AnonParam1);
 }
 
-void QWidget_setMask2(QWidgetH handle, const QRegionH p1)
+void QWidget_setMask2(QWidgetH handle, const QRegionH AnonParam1)
 {
-	((QWidget *)handle)->setMask(*(const QRegion*)p1);
+	((QWidget *)handle)->setMask(*(const QRegion*)AnonParam1);
 }
 
 void QWidget_mask(QWidgetH handle, QRegionH retval)
@@ -461,11 +461,11 @@ void QWidget_render2(QWidgetH handle, QPainterH painter, const QPointH targetOff
 	((QWidget *)handle)->render((QPainter*)painter, *(const QPoint*)targetOffset, *(const QRegion*)sourceRegion, (QWidget::RenderFlags)renderFlags);
 }
 
-void QWidget_setWindowTitle(QWidgetH handle, PWideString p1)
+void QWidget_setWindowTitle(QWidgetH handle, PWideString AnonParam1)
 {
-	QString t_p1;
-	copyPWideStringToQString(p1, t_p1);
-	((QWidget *)handle)->setWindowTitle(t_p1);
+	QString t_AnonParam1;
+	copyPWideStringToQString(AnonParam1, t_AnonParam1);
+	((QWidget *)handle)->setWindowTitle(t_AnonParam1);
 }
 
 void QWidget_setStyleSheet(QWidgetH handle, PWideString styleSheet)
@@ -499,11 +499,11 @@ void QWidget_windowIcon(QWidgetH handle, QIconH retval)
 	*(QIcon *)retval = ((QWidget *)handle)->windowIcon();
 }
 
-void QWidget_setWindowIconText(QWidgetH handle, PWideString p1)
+void QWidget_setWindowIconText(QWidgetH handle, PWideString AnonParam1)
 {
-	QString t_p1;
-	copyPWideStringToQString(p1, t_p1);
-	((QWidget *)handle)->setWindowIconText(t_p1);
+	QString t_AnonParam1;
+	copyPWideStringToQString(AnonParam1, t_AnonParam1);
+	((QWidget *)handle)->setWindowIconText(t_AnonParam1);
 }
 
 void QWidget_windowIconText(QWidgetH handle, PWideString retval)
@@ -513,11 +513,11 @@ void QWidget_windowIconText(QWidgetH handle, PWideString retval)
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QWidget_setWindowRole(QWidgetH handle, PWideString p1)
+void QWidget_setWindowRole(QWidgetH handle, PWideString AnonParam1)
 {
-	QString t_p1;
-	copyPWideStringToQString(p1, t_p1);
-	((QWidget *)handle)->setWindowRole(t_p1);
+	QString t_AnonParam1;
+	copyPWideStringToQString(AnonParam1, t_AnonParam1);
+	((QWidget *)handle)->setWindowRole(t_AnonParam1);
 }
 
 void QWidget_windowRole(QWidgetH handle, PWideString retval)
@@ -556,11 +556,11 @@ bool QWidget_isWindowModified(QWidgetH handle)
 	return (bool) ((QWidget *)handle)->isWindowModified();
 }
 
-void QWidget_setToolTip(QWidgetH handle, PWideString p1)
+void QWidget_setToolTip(QWidgetH handle, PWideString AnonParam1)
 {
-	QString t_p1;
-	copyPWideStringToQString(p1, t_p1);
-	((QWidget *)handle)->setToolTip(t_p1);
+	QString t_AnonParam1;
+	copyPWideStringToQString(AnonParam1, t_AnonParam1);
+	((QWidget *)handle)->setToolTip(t_AnonParam1);
 }
 
 void QWidget_toolTip(QWidgetH handle, PWideString retval)
@@ -570,11 +570,11 @@ void QWidget_toolTip(QWidgetH handle, PWideString retval)
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QWidget_setStatusTip(QWidgetH handle, PWideString p1)
+void QWidget_setStatusTip(QWidgetH handle, PWideString AnonParam1)
 {
-	QString t_p1;
-	copyPWideStringToQString(p1, t_p1);
-	((QWidget *)handle)->setStatusTip(t_p1);
+	QString t_AnonParam1;
+	copyPWideStringToQString(AnonParam1, t_AnonParam1);
+	((QWidget *)handle)->setStatusTip(t_AnonParam1);
 }
 
 void QWidget_statusTip(QWidgetH handle, PWideString retval)
@@ -584,11 +584,11 @@ void QWidget_statusTip(QWidgetH handle, PWideString retval)
 	copyQStringToPWideString(t_retval, retval);
 }
 
-void QWidget_setWhatsThis(QWidgetH handle, PWideString p1)
+void QWidget_setWhatsThis(QWidgetH handle, PWideString AnonParam1)
 {
-	QString t_p1;
-	copyPWideStringToQString(p1, t_p1);
-	((QWidget *)handle)->setWhatsThis(t_p1);
+	QString t_AnonParam1;
+	copyPWideStringToQString(AnonParam1, t_AnonParam1);
+	((QWidget *)handle)->setWhatsThis(t_AnonParam1);
 }
 
 void QWidget_whatsThis(QWidgetH handle, PWideString retval)
@@ -706,14 +706,14 @@ bool QWidget_hasFocus(QWidgetH handle)
 	return (bool) ((QWidget *)handle)->hasFocus();
 }
 
-void QWidget_setTabOrder(QWidgetH p1, QWidgetH p2)
+void QWidget_setTabOrder(QWidgetH AnonParam1, QWidgetH AnonParam2)
 {
-	QWidget::setTabOrder((QWidget*)p1, (QWidget*)p2);
+	QWidget::setTabOrder((QWidget*)AnonParam1, (QWidget*)AnonParam2);
 }
 
-void QWidget_setFocusProxy(QWidgetH handle, QWidgetH p1)
+void QWidget_setFocusProxy(QWidgetH handle, QWidgetH AnonParam1)
 {
-	((QWidget *)handle)->setFocusProxy((QWidget*)p1);
+	((QWidget *)handle)->setFocusProxy((QWidget*)AnonParam1);
 }
 
 QWidgetH QWidget_focusProxy(QWidgetH handle)
@@ -736,9 +736,9 @@ void QWidget_grabMouse(QWidgetH handle)
 	((QWidget *)handle)->grabMouse();
 }
 
-void QWidget_grabMouse2(QWidgetH handle, const QCursorH p1)
+void QWidget_grabMouse2(QWidgetH handle, const QCursorH AnonParam1)
 {
-	((QWidget *)handle)->grabMouse(*(const QCursor*)p1);
+	((QWidget *)handle)->grabMouse(*(const QCursor*)AnonParam1);
 }
 
 void QWidget_releaseMouse(QWidgetH handle)
@@ -816,16 +816,16 @@ void QWidget_update2(QWidgetH handle, int x, int y, int w, int h)
 	((QWidget *)handle)->update(x, y, w, h);
 }
 
-void QWidget_update3(QWidgetH handle, PRect p1)
+void QWidget_update3(QWidgetH handle, PRect AnonParam1)
 {
-	QRect t_p1;
-	copyPRectToQRect(p1, t_p1);
-	((QWidget *)handle)->update(t_p1);
+	QRect t_AnonParam1;
+	copyPRectToQRect(AnonParam1, t_AnonParam1);
+	((QWidget *)handle)->update(t_AnonParam1);
 }
 
-void QWidget_update4(QWidgetH handle, const QRegionH p1)
+void QWidget_update4(QWidgetH handle, const QRegionH AnonParam1)
 {
-	((QWidget *)handle)->update(*(const QRegion*)p1);
+	((QWidget *)handle)->update(*(const QRegion*)AnonParam1);
 }
 
 void QWidget_repaint2(QWidgetH handle, int x, int y, int w, int h)
@@ -833,16 +833,16 @@ void QWidget_repaint2(QWidgetH handle, int x, int y, int w, int h)
 	((QWidget *)handle)->repaint(x, y, w, h);
 }
 
-void QWidget_repaint3(QWidgetH handle, PRect p1)
+void QWidget_repaint3(QWidgetH handle, PRect AnonParam1)
 {
-	QRect t_p1;
-	copyPRectToQRect(p1, t_p1);
-	((QWidget *)handle)->repaint(t_p1);
+	QRect t_AnonParam1;
+	copyPRectToQRect(AnonParam1, t_AnonParam1);
+	((QWidget *)handle)->repaint(t_AnonParam1);
 }
 
-void QWidget_repaint4(QWidgetH handle, const QRegionH p1)
+void QWidget_repaint4(QWidgetH handle, const QRegionH AnonParam1)
 {
-	((QWidget *)handle)->repaint(*(const QRegion*)p1);
+	((QWidget *)handle)->repaint(*(const QRegion*)AnonParam1);
 }
 
 void QWidget_setVisible(QWidgetH handle, bool visible)
@@ -905,9 +905,9 @@ void QWidget_lower(QWidgetH handle)
 	((QWidget *)handle)->lower();
 }
 
-void QWidget_stackUnder(QWidgetH handle, QWidgetH p1)
+void QWidget_stackUnder(QWidgetH handle, QWidgetH AnonParam1)
 {
-	((QWidget *)handle)->stackUnder((QWidget*)p1);
+	((QWidget *)handle)->stackUnder((QWidget*)AnonParam1);
 }
 
 void QWidget_move(QWidgetH handle, int x, int y)
@@ -915,9 +915,9 @@ void QWidget_move(QWidgetH handle, int x, int y)
 	((QWidget *)handle)->move(x, y);
 }
 
-void QWidget_move2(QWidgetH handle, const QPointH p1)
+void QWidget_move2(QWidgetH handle, const QPointH AnonParam1)
 {
-	((QWidget *)handle)->move(*(const QPoint*)p1);
+	((QWidget *)handle)->move(*(const QPoint*)AnonParam1);
 }
 
 void QWidget_resize(QWidgetH handle, int w, int h)
@@ -925,9 +925,9 @@ void QWidget_resize(QWidgetH handle, int w, int h)
 	((QWidget *)handle)->resize(w, h);
 }
 
-void QWidget_resize2(QWidgetH handle, const QSizeH p1)
+void QWidget_resize2(QWidgetH handle, const QSizeH AnonParam1)
 {
-	((QWidget *)handle)->resize(*(const QSize*)p1);
+	((QWidget *)handle)->resize(*(const QSize*)AnonParam1);
 }
 
 void QWidget_setGeometry(QWidgetH handle, int x, int y, int w, int h)
@@ -935,11 +935,11 @@ void QWidget_setGeometry(QWidgetH handle, int x, int y, int w, int h)
 	((QWidget *)handle)->setGeometry(x, y, w, h);
 }
 
-void QWidget_setGeometry2(QWidgetH handle, PRect p1)
+void QWidget_setGeometry2(QWidgetH handle, PRect AnonParam1)
 {
-	QRect t_p1;
-	copyPRectToQRect(p1, t_p1);
-	((QWidget *)handle)->setGeometry(t_p1);
+	QRect t_AnonParam1;
+	copyPRectToQRect(AnonParam1, t_AnonParam1);
+	((QWidget *)handle)->setGeometry(t_AnonParam1);
 }
 
 void QWidget_saveGeometry(QWidgetH handle, QByteArrayH retval)
@@ -962,9 +962,9 @@ bool QWidget_isVisible(QWidgetH handle)
 	return (bool) ((QWidget *)handle)->isVisible();
 }
 
-bool QWidget_isVisibleTo(QWidgetH handle, QWidgetH p1)
+bool QWidget_isVisibleTo(QWidgetH handle, QWidgetH AnonParam1)
 {
-	return (bool) ((QWidget *)handle)->isVisibleTo((QWidget*)p1);
+	return (bool) ((QWidget *)handle)->isVisibleTo((QWidget*)AnonParam1);
 }
 
 bool QWidget_isHidden(QWidgetH handle)
@@ -1012,14 +1012,14 @@ void QWidget_minimumSizeHint(QWidgetH handle, PSize retval)
 	*(QSize *)retval = ((QWidget *)handle)->minimumSizeHint();
 }
 
-void QWidget_sizePolicy(QWidgetH handle, PSizePolicy retval)
+void QWidget_sizePolicy(QWidgetH handle, PQSizePolicy retval)
 {
 	*(QSizePolicy *)retval = ((QWidget *)handle)->sizePolicy();
 }
 
-void QWidget_setSizePolicy(QWidgetH handle, PSizePolicy p1)
+void QWidget_setSizePolicy(QWidgetH handle, PQSizePolicy AnonParam1)
 {
-	((QWidget *)handle)->setSizePolicy(*(QSizePolicy *)p1);
+	((QWidget *)handle)->setSizePolicy(*(QSizePolicy *)AnonParam1);
 }
 
 void QWidget_setSizePolicy2(QWidgetH handle, QSizePolicy::Policy horizontal, QSizePolicy::Policy vertical)
@@ -1027,9 +1027,9 @@ void QWidget_setSizePolicy2(QWidgetH handle, QSizePolicy::Policy horizontal, QSi
 	((QWidget *)handle)->setSizePolicy(horizontal, vertical);
 }
 
-int QWidget_heightForWidth(QWidgetH handle, int p1)
+int QWidget_heightForWidth(QWidgetH handle, int AnonParam1)
 {
-	return (int) ((QWidget *)handle)->heightForWidth(p1);
+	return (int) ((QWidget *)handle)->heightForWidth(AnonParam1);
 }
 
 void QWidget_visibleRegion(QWidgetH handle, QRegionH retval)
@@ -1059,9 +1059,9 @@ QLayoutH QWidget_layout(QWidgetH handle)
 	return (QLayoutH) ((QWidget *)handle)->layout();
 }
 
-void QWidget_setLayout(QWidgetH handle, QLayoutH p1)
+void QWidget_setLayout(QWidgetH handle, QLayoutH AnonParam1)
 {
-	((QWidget *)handle)->setLayout((QLayout*)p1);
+	((QWidget *)handle)->setLayout((QLayout*)AnonParam1);
 }
 
 void QWidget_updateGeometry(QWidgetH handle)
@@ -1084,11 +1084,11 @@ void QWidget_scroll(QWidgetH handle, int dx, int dy)
 	((QWidget *)handle)->scroll(dx, dy);
 }
 
-void QWidget_scroll2(QWidgetH handle, int dx, int dy, PRect p3)
+void QWidget_scroll2(QWidgetH handle, int dx, int dy, PRect AnonParam3)
 {
-	QRect t_p3;
-	copyPRectToQRect(p3, t_p3);
-	((QWidget *)handle)->scroll(dx, dy, t_p3);
+	QRect t_AnonParam3;
+	copyPRectToQRect(AnonParam3, t_AnonParam3);
+	((QWidget *)handle)->scroll(dx, dy, t_AnonParam3);
 }
 
 QWidgetH QWidget_focusWidget(QWidgetH handle)
@@ -1172,9 +1172,9 @@ Qt::WindowType QWidget_windowType(QWidgetH handle)
 	return (Qt::WindowType) ((QWidget *)handle)->windowType();
 }
 
-QWidgetH QWidget_find(unsigned int p1)
+QWidgetH QWidget_find(unsigned int AnonParam1)
 {
-	return (QWidgetH) QWidget::find((WId)p1);
+	return (QWidgetH) QWidget::find((WId)AnonParam1);
 }
 
 QWidgetH QWidget_childAt(QWidgetH handle, int x, int y)
@@ -1206,14 +1206,14 @@ Qt::HANDLE QWidget_handle(QWidgetH handle)
 }
 
 #endif
-void QWidget_setAttribute(QWidgetH handle, Qt::WidgetAttribute p1, bool on)
+void QWidget_setAttribute(QWidgetH handle, Qt::WidgetAttribute AnonParam1, bool on)
 {
-	((QWidget *)handle)->setAttribute(p1, on);
+	((QWidget *)handle)->setAttribute(AnonParam1, on);
 }
 
-bool QWidget_testAttribute(QWidgetH handle, Qt::WidgetAttribute p1)
+bool QWidget_testAttribute(QWidgetH handle, Qt::WidgetAttribute AnonParam1)
 {
-	return (bool) ((QWidget *)handle)->testAttribute(p1);
+	return (bool) ((QWidget *)handle)->testAttribute(AnonParam1);
 }
 
 QPaintEngineH QWidget_paintEngine(QWidgetH handle)
@@ -1231,9 +1231,9 @@ QInputContextH QWidget_inputContext(QWidgetH handle)
 	return (QInputContextH) ((QWidget *)handle)->inputContext();
 }
 
-void QWidget_setInputContext(QWidgetH handle, QInputContextH p1)
+void QWidget_setInputContext(QWidgetH handle, QInputContextH AnonParam1)
 {
-	((QWidget *)handle)->setInputContext((QInputContext*)p1);
+	((QWidget *)handle)->setInputContext((QInputContext*)AnonParam1);
 }
 
 bool QWidget_isAncestorOf(QWidgetH handle, const QWidgetH child)
@@ -1251,9 +1251,9 @@ void QWidget_setAutoFillBackground(QWidgetH handle, bool enabled)
 	((QWidget *)handle)->setAutoFillBackground(enabled);
 }
 
-void QWidget_inputMethodQuery(QWidgetH handle, QVariantH retval, Qt::InputMethodQuery p1)
+void QWidget_inputMethodQuery(QWidgetH handle, QVariantH retval, Qt::InputMethodQuery AnonParam1)
 {
-	*(QVariant *)retval = ((QWidget *)handle)->inputMethodQuery(p1);
+	*(QVariant *)retval = ((QWidget *)handle)->inputMethodQuery(AnonParam1);
 }
 
 #if defined MSWINDOWS
@@ -1262,9 +1262,9 @@ HDC QWidget_getDC(QWidgetH handle)
 	return (HDC) ((QWidget *)handle)->getDC();
 }
 
-void QWidget_releaseDC(QWidgetH handle, HDC p1)
+void QWidget_releaseDC(QWidgetH handle, HDC AnonParam1)
 {
-	((QWidget *)handle)->releaseDC(p1);
+	((QWidget *)handle)->releaseDC(AnonParam1);
 }
 
 #endif
